cumulusci.tasks.tests package
=============================

Submodules
----------


.. automodule:: cumulusci.tasks.tests.test_command
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_connectedapp
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_datadictionary
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_metadeploy
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_metaxml
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_pushfails
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_salesforce
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_sfdx
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.tests.test_util
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.tests
   :members:
   :undoc-members:
   :show-inheritance:
